@@ -32,6 +32,13 @@ class RunSklearnClf(BaseEstimator):
         return {
             "metric": self.args.metric,
             "model": self.args.model,
+            "dataset_name": self.args.dataset,  # Required for saving fitted models
+            "dataset": [
+                f"{self.args.dataset}/X_train_{self.container_name}.csv",
+                f"{self.args.dataset}/y_train_{self.container_name}.csv",
+                f"{self.args.dataset}/X_test_{self.container_name}.csv",
+                f"{self.args.dataset}/y_test_{self.container_name}.csv"
+            ],
             "params": None,
         }
 
