@@ -32,4 +32,11 @@ class RunXGBoostClf(BaseEstimator):
         return {
             "metric": self.args.metric,
             "model": self.args.model,
+            "dataset_name": self.args.dataset,  # Required for saving fitted models
+            "dataset": [
+                f"{self.args.dataset}/X_train_{self.container_name}.csv",
+                f"{self.args.dataset}/y_train_{self.container_name}.csv",
+                f"{self.args.dataset}/X_test_{self.container_name}.csv",
+                f"{self.args.dataset}/y_test_{self.container_name}.csv"
+            ],
         }
\ No newline at end of file
