@@ -29,8 +29,15 @@ class RunImblearnSampler(BaseTransformer):
 
     @property
     def payload(self):
+        # Resamplers only work on training data to balance classes
+        # Test data should NEVER be resampled - it must maintain real-world distribution
         return {
             "metric": self.args.metric,
             "model": self.args.model,
+            "dataset_name": self.args.dataset,  # Required for saving results
+            "dataset": [
+                f"{self.args.dataset}/X_train_{self.container_name}.csv",
+                f"{self.args.dataset}/y_train_{self.container_name}.csv",
+            ],
         }
 
